#
# spec file for package sundials
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor openmpi4%{nil}

%define pname sundials

%if 0%{?is_opensuse} || 0%{?is_backports}
%undefine DisOMPI1
%undefine DisOMPI2
%undefine DisOMPI3
%undefine DisOMPI4
%else
%define DisOMPI1 ExclusiveArch:  do_not_build
%define DisOMPI3 ExclusiveArch:  do_not_build
%define DisOMPI4 ExclusiveArch:  do_not_build
%undefine DisOMPI2
%endif

%if "%{flavor}" == ""
%define package_name %{pname}
ExclusiveArch:  do_not_build
%endif

%if "%{flavor}" == "mvapich2"
%global mpi_flavor mvapich2
%global mpi_version >= 2.3.7
%endif

%if "%{flavor}" == "openmpi4"
%global mpi_flavor openmpi
%define mpi_vers 4
%{?DisOMPI4}
%endif

%if "%{flavor}" == "openmpi5"
%global mpi_flavor openmpi
%define mpi_vers 5
%{?DisOMPI5}
%endif

%{?mpi_flavor:%{bcond_without mpi}}%{!?mpi_flavor:%{bcond_with mpi}}
%{?with_mpi:%{!?mpi_flavor:error "No MPI family specified!"}}

# For compatibility package names
%define mpi_ext %{?mpi_vers}

%if %{without mpi}
 %define my_prefix %_prefix
 %define my_bindir %_bindir
 %define my_libdir %_libdir
 %define my_incdir %_includedir
%else
 %define my_prefix %{_libdir}/mpi/gcc/%{mpi_flavor}%{?mpi_ext}
 %define my_bindir %{my_prefix}/bin
 %define my_libdir %{my_prefix}/%_lib
 %define my_incdir %{my_prefix}/include
 %define my_suffix -%{mpi_flavor}%{?mpi_ext}
%endif

%if 0%{!?package_name:1}
 %define package_name   %pname%{?my_suffix}
%endif

# /SECTION

%define shlib_arkode    libsundials_arkode6%{?my_suffix}
%define shlib_cvode     libsundials_cvode7%{?my_suffix}
%define shlib_cvodes    libsundials_cvodes7%{?my_suffix}
%define shlib_core      libsundials_core7%{?my_suffix}
%define shlib_ida       libsundials_ida7%{?my_suffix}
%define shlib_idas      libsundials_idas6%{?my_suffix}
%define shlib_kinsol    libsundials_kinsol7%{?my_suffix}
%define shlib_nvec      libsundials_nvec7%{?my_suffix}
%define shlib_sunlinsol libsundials_sunlinsol5%{?my_suffix}
%define shlib_sunmatrix libsundials_sunmatrix5%{?my_suffix}
%define shlib_sunnonlin libsundials_sunnonlin4%{?my_suffix}

Name:           %{package_name}
Version:        7.1.1
Release:        1.2
Summary:        Suite of nonlinear solvers
# SUNDIALS is licensed under BSD with some additional (but unrestrictive) clauses.
# Check the file 'LICENSE' for details.
License:        BSD-3-Clause
URL:            https://computing.llnl.gov/projects/sundials
Source0:        https://github.com/LLNL/%{pname}/releases/download/v%{version}/%{pname}-%{version}.tar.gz
Group:          Development/Libraries/Parallel
BuildRequires:  blas-devel
BuildRequires:  cmake >= 3.12
BuildRequires:  fdupes
BuildRequires:  gcc-fortran
BuildRequires:  lapack-devel
BuildRequires:  suitesparse-devel
%if %{with mpi}
BuildRequires:  %{mpi_flavor}%{?mpi_ext}-devel %{?mpi_version}
%if 0%{?suse_version} >= 1550 && "%{flavor}" != "mvapich2"
# hackish workaround for multiple openmpX-config all providing openmpX-runtime-config
BuildRequires:  %{mpi_flavor}%{?mpi_ext}-config
%endif
%endif

%description
SUNDIALS is a SUite of Non-linear DIfferential/ALgebraic equation Solvers
for use in writing mathematical software.

SUNDIALS was implemented with the goal of providing robust time integrators
and nonlinear solvers that can easily be incorporated into existing simulation
codes. The primary design goals were to require minimal information from the
user, allow users to easily supply their own data structures underneath the
solvers, and allow for easy incorporation of user-supplied linear solvers and
preconditioners.

%package devel
Summary:        Suite of nonlinear solvers (developer files)
Requires:       %{shlib_arkode} = %{version}
Requires:       %{shlib_core} = %{version}
Requires:       %{shlib_cvodes} = %{version}
Requires:       %{shlib_cvode} = %{version}
Requires:       %{shlib_idas} = %{version}
Requires:       %{shlib_ida} = %{version}
Requires:       %{shlib_kinsol} = %{version}
Requires:       %{shlib_nvec} = %{version}
Requires:       %{shlib_sunlinsol} = %{version}
Requires:       %{shlib_sunmatrix} = %{version}
Requires:       %{shlib_sunnonlin} = %{version}

%description devel
SUNDIALS is a SUite of Non-linear DIfferential/ALgebraic equation Solvers
for use in writing mathematical software.

This package contains the developer files (.so file, header files)

%package doc
Summary:        Suite of nonlinear solvers (documentation)
BuildArch:      noarch

%description doc
SUNDIALS is a SUite of Non-linear DIfferential/ALgebraic equation Solvers
for use in writing mathematical software.

This package contains the documentation files

%package -n %{shlib_arkode}
Summary:        Suite of nonlinear solvers - arkode shared libraries

%description -n %{shlib_arkode}
SUNDIALS is a SUite of Non-linear DIfferential/ALgebraic equation Solvers
for use in writing mathematical software.

This package provides the shared libraries for SUNDIALS' arkode solver.

%package -n %{shlib_cvode}
Summary:        Suite of nonlinear solvers - cvode shared libraries

%description -n %{shlib_cvode}
SUNDIALS is a SUite of Non-linear DIfferential/ALgebraic equation Solvers
for use in writing mathematical software.

This package provides the shared libraries for SUNDIALS' cvode solver.

%package -n %{shlib_cvodes}
Summary:        Suite of nonlinear solvers - cvodes shared libraries

%description -n %{shlib_cvodes}
SUNDIALS is a SUite of Non-linear DIfferential/ALgebraic equation Solvers
for use in writing mathematical software.

This package provides the shared libraries for SUNDIALS' cvodes solver.

%package -n %{shlib_core}
Summary:        Suite of nonlinear solvers - generic shared libraries

%description -n %{shlib_core}
SUNDIALS is a SUite of Non-linear DIfferential/ALgebraic equation Solvers
for use in writing mathematical software.

This package provides the shared libraries for SUNDIALS' generic solver.

%package -n %{shlib_ida}
Summary:        Suite of nonlinear solvers - ida shared libraries

%description -n %{shlib_ida}
SUNDIALS is a SUite of Non-linear DIfferential/ALgebraic equation Solvers
for use in writing mathematical software.

This package provides the shared libraries for SUNDIALS' ida solver.

%package -n %{shlib_idas}
Summary:        Suite of nonlinear solvers - idas shared libraries

%description -n %{shlib_idas}
SUNDIALS is a SUite of Non-linear DIfferential/ALgebraic equation Solvers
for use in writing mathematical software.

This package provides the shared libraries for SUNDIALS' idas solver.

%package -n %{shlib_kinsol}
Summary:        Suite of nonlinear solvers - kinsol shared libraries

%description -n %{shlib_kinsol}
SUNDIALS is a SUite of Non-linear DIfferential/ALgebraic equation Solvers
for use in writing mathematical software.

This package provides the shared libraries for SUNDIALS' kinsol solver.

%package -n %{shlib_nvec}
Summary:        Suite of nonlinear solvers - nvec shared libraries

%description -n %{shlib_nvec}
SUNDIALS is a SUite of Non-linear DIfferential/ALgebraic equation Solvers
for use in writing mathematical software.

This package provides the shared libraries for SUNDIALS' nvec solvers.

%package -n %{shlib_sunlinsol}
Summary:        Suite of nonlinear solvers - sunlinsol shared libraries
# Required to break libsundials_sunmatrix-<flavour> degeneracy in dependent packages
Requires:       %{shlib_sunmatrix} = %{version}

%description -n %{shlib_sunlinsol}
SUNDIALS is a SUite of Non-linear DIfferential/ALgebraic equation Solvers
for use in writing mathematical software.

This package provides the sunlinsol shared libraries for SUNDIALS.

%package -n %{shlib_sunmatrix}
Summary:        Suite of nonlinear solvers - sunmatrix shared libraries
Conflicts:      libsundials4%{?my_suffix}

%description -n %{shlib_sunmatrix}
SUNDIALS is a SUite of Non-linear DIfferential/ALgebraic equation Solvers
for use in writing mathematical software.

This package provides the sunmatrix shared libraries for SUNDIALS.

%package -n %{shlib_sunnonlin}
Summary:        Suite of nonlinear solvers - sunnonlin shared libraries
Conflicts:      libsundials4%{?my_suffix}

%description -n %{shlib_sunnonlin}
SUNDIALS is a SUite of Non-linear DIfferential/ALgebraic equation Solvers
for use in writing mathematical software.

This package provides the sunnonlin shared libraries for SUNDIALS.

%prep
%autosetup -p1 -n %{pname}-%{version}

%build
%cmake \
       -DCMAKE_INSTALL_PREFIX=%{my_prefix} \
       -DCMAKE_INSTALL_LIBDIR=%{my_libdir} \
%if "%{?_lib}" == "lib64"
       -DLIB_SUFFIX=64 \
%endif
       -DCMAKE_SKIP_RPATH:BOOL=OFF \
       -DCMAKE_SKIP_INSTALL_RPATH:BOOL=ON \
       -DENABLE_LAPACK:BOOL=ON \
       -DENABLE_PTHREAD:BOOL=ON \
       -DENABLE_KLU:BOOL=ON \
       -DKLU_INCLUDE_DIR:PATH=%{_includedir}/suitesparse \
       -DKLU_LIBRARY_DIR:PATH=%{_libdir} \
       -DSUNDIALS_BUILD_WITH_MONITORING:BOOL=ON \
%if %{without mpi}
       -DEXAMPLES_INSTALL_PATH=%{_docdir}/%{name}/examples \
       -DENABLE_MPI:BOOL=OFF
%else
       -DEXAMPLES_INSTALL:BOOL=OFF \
       -DENABLE_MPI:BOOL=ON \
       -DMPI_C_COMPILER=%{my_bindir}/mpicc \
       -DMPI_CXX_COMPILER=%{my_bindir}/mpicxx \
       -DMPI_Fortran_COMPILER=%{my_bindir}/mpif90 \
       -DMPIEXEC_EXECUTABLE=%{my_bindir}/mpirun
%endif

%cmake_build

%install
%cmake_install

rm %{buildroot}%{my_incdir}/sundials/{NOTICE,LICENSE}

%fdupes %{buildroot}

%check
# Send extremely verbose output to a log file instead of printing to screen to avoid build log bloat
# Disable the sunlinsol tests which fail apparently due to minor floating pt issues
# On 32-bit, also disable the sunmatrix tests which fail due to minor floating pt issues
%if %{with mpi}
. %{my_bindir}/mpivars.sh

# mavpich2 seems to have issues with CMA depending on runs!?
# As this is for testing only, always disable it so it just works.
export MV2_SMP_USE_CMA=0

# Enable the necessary flags so it works on less than 4 cores
if [ "$(grep 'core id' /proc/cpuinfo  | wc -l)" -lt 4 ]; then
    # For mvapich2
    export MV2_ENABLE_AFFINITY=0
    # For openMPI >= 5.x
    export PRTE_MCA_rmaps_default_mapping_policy=:oversubscribe
    # For openMPI < 5
    export OMPI_MCA_rmaps_base_oversubscribe=1
fi
%endif
%ifarch %ix86
%ctest --quiet --output-log test-output.log --exclude-regex "test_(sunlinsol_lapack|sunmatrix_sparse)*" || ( grep "Fail" test-output.log; exit 1 )
%else
%ctest --quiet --output-log test-output.log --exclude-regex "test_sunlinsol_lapack*" || ( grep "Fail" test-output.log; exit 1; )
%endif

%post -n %{shlib_arkode} -p /sbin/ldconfig
%postun -n %{shlib_arkode} -p /sbin/ldconfig

%post -n %{shlib_cvode} -p /sbin/ldconfig
%postun -n %{shlib_cvode} -p /sbin/ldconfig

%post -n %{shlib_cvodes} -p /sbin/ldconfig
%postun -n %{shlib_cvodes} -p /sbin/ldconfig

%post -n %{shlib_core} -p /sbin/ldconfig
%postun -n %{shlib_core} -p /sbin/ldconfig

%post -n %{shlib_ida} -p /sbin/ldconfig
%postun -n %{shlib_ida} -p /sbin/ldconfig

%post -n %{shlib_idas} -p /sbin/ldconfig
%postun -n %{shlib_idas} -p /sbin/ldconfig

%post -n %{shlib_kinsol} -p /sbin/ldconfig
%postun -n %{shlib_kinsol} -p /sbin/ldconfig

%post -n %{shlib_nvec} -p /sbin/ldconfig
%postun -n %{shlib_nvec} -p /sbin/ldconfig

%post -n %{shlib_sunlinsol} -p /sbin/ldconfig
%postun -n %{shlib_sunlinsol} -p /sbin/ldconfig

%post -n %{shlib_sunmatrix} -p /sbin/ldconfig
%postun -n %{shlib_sunmatrix} -p /sbin/ldconfig

%post -n %{shlib_sunnonlin} -p /sbin/ldconfig
%postun -n %{shlib_sunnonlin} -p /sbin/ldconfig

%if %{without mpi}
%files doc
%doc doc/cvode/cv_examples.pdf
%doc doc/cvode/cv_guide.pdf
%doc doc/kinsol/kin_examples.pdf
%doc doc/kinsol/kin_guide.pdf
%doc doc/cvodes/cvs_examples.pdf
%doc doc/cvodes/cvs_guide.pdf
%doc doc/ida/ida_examples.pdf
%doc doc/ida/ida_guide.pdf
%{_docdir}/%{name}/
%endif

%files devel
%license LICENSE
%doc README.md CONTRIBUTING.md NOTICE
%{my_libdir}/*.so
%{my_incdir}/*
%if %{with mpi}
%dir %{my_libdir}/cmake
%endif
%{my_libdir}/cmake/sundials/

%files -n %{shlib_arkode}
%{my_libdir}/libsundials_arkode.so.*

%files -n %{shlib_cvode}
%{my_libdir}/libsundials_cvode.so.*

%files -n %{shlib_cvodes}
%{my_libdir}/libsundials_cvodes.so.*

%files -n %{shlib_core}
%{my_libdir}/libsundials_core.so.*

%files -n %{shlib_ida}
%{my_libdir}/libsundials_ida.so.*

%files -n %{shlib_idas}
%{my_libdir}/libsundials_idas.so.*

%files -n %{shlib_kinsol}
%{my_libdir}/libsundials_kinsol.so.*

%files -n %{shlib_nvec}
%{my_libdir}/libsundials_nvec*.so.*

%files -n %{shlib_sunlinsol}
%{my_libdir}/libsundials_sunlinsol*.so.*

%files -n %{shlib_sunmatrix}
%{my_libdir}/libsundials_sunmatrix*.so.*

%files -n %{shlib_sunnonlin}
%{my_libdir}/libsundials_sunnonlin*.so.*

%changelog
* Wed Jul 17 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 7.1.1:
  * Fixed a bug in v7.1.0 with the SYCL N_Vector N_VSpace
  * function (gh#LLNL/sundials#523).
- Changes from version 7.1.0:
  * Too many to list, see
    <https://github.com/LLNL/sundials/releases/tag/v7.1.0>.
* Tue Mar 12 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 7.0.0:
  * Many changes, see
    https://github.com/LLNL/sundials/releases/tag/v7.0.0.
- Update shared library package names in keeping with upstream
  so version bumps.
- Adapt to name change of shared library: libsundials_generic ->
  libsundials_core.
* Tue Feb 20 2024 Nicolas Morey <nicolas.morey@suse.com>
- Load the full mpivars instead of manually setting LD_LIBRARY_PATH
- Add flags to handle oversubscription for %%check (bsc#1201273).
  _constraints avoids this in OBS, but local runs may not have 4
  cores available.
* Tue Dec 19 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 6.7.0:
  * Many changes, see
    https://github.com/LLNL/sundials/releases/tag/v6.7.0.
- Adapt shlib names for sunlinsol and sunnonlin libraries in
  keeping with upstream so versioning changes.
* Sun Dec  3 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 6.6.2:
  * Fixed build system support for MAGMA when using a NVIDIA HPC
    SDK installation of CUDA
  * Fixed targets used for rocBLAS and rocSPARSE.
- Changes from version 6.6.1:
  * Updated the Tpetra NVector interface to support Trilinos 14.
  * Fixed a memory leak when destroying a CUDA, HIP, SYCL, or
    system SUNMemoryHelper object.
  * Fixed a bug in ARKODE, CVODE, CVODES, IDA, and IDAS where the
    stop time may not be cleared when using normal mode if the
    requested output time is the same as the stop time.
- Changes from versio 6.6.0:
  * A new time-stepping module, SPRKStep, was added to ARKODE.
    This time-stepper provides explicit symplectic partitioned
    Runge-Kutta methods up to order 10 for separable Hamiltonian
    systems.
  * Added support for relaxation Runge-Kutta methods to ERKStep
    and ARKStep in ARKODE.
  * Added the second order IMEX method from Giraldo, Kelly, and
    Constantinescu 2013 as the default second order IMEX method in
    ARKStep.
  * Updated CVODE, CVODES and ARKODE default behavior when
    returning the solution when the internal time has reached a
    user-specified stop time.
  * A potential bug was fixed when using inequality constraint
    handling and calling ARKStepGetEstLocalErrors or
    ERKStepGetEstLocalErrors after a failed step in which an
    inequality constraint violation occurred.
  * Updated the F2003 utility routines SUNDIALSFileOpen and
    SUNDIALSFileClose to support user specification of stdout and
    stderr strings for the output file names.
- Changes from older releases: see
  https://computing.llnl.gov/projects/sundials/release-history
- Drop sundials-link-pthread.patch: fixed upstream.
- Bump so versions in keeping with upstream.
* Mon Oct 23 2023 Nicolas Morey <nicolas.morey@suse.com>
- Drop support for obsolete openmpi[123]
- Prepare support for openmpi5
* Sat Sep 17 2022 Atri Bhattacharya <badshah400@gmail.com>
- Add Requires: libsundials_sunmatrix4 explicitly for
  libsundials_sunlinsol4_3_0; automatic deps fails to distinguish
  between serial and mpi flavors causing resolving issues when
  building apps dependent on libsundials_sunlinsol.
* Wed Sep 14 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 6.3.0:
  * Added GetUserData functions in each package to retrieve the
    user data pointer provided to SetUserData functions
  * Fixed a bug in ERKStepReset, ERKStepReInit, ARKStepReset,
    ARKStepReInit, MRIStepReset, and MRIStepReInit where a
    previously-set value of tstop (from a call to
    ERKStepSetStopTime, ARKStepSetStopTime, or MRIStepSetStopTime,
    respectively) would not be cleared.
  * Updated MRIStepReset to call the corresponding
    MRIStepInnerResetFn with the same (tR,yR) arguments for the
    MRIStepInnerStepper object that is used to evolve the MRI
    "fast" time scale subproblems.
  * Added a new example which demonstrates using CVODE with a
    discontinuous right-hand-side function and rootfinding.
  * Added a variety of embedded DIRK methods from [Kennedy &
    Carpenter, NASA TM-2016-219173, 2016] and [Kennedy &
    Carpenter, Appl. Numer. Math., 146, 2019] to ARKODE.
  * Fixed the unintuitive behavior of the USE_GENERIC_MATH CMake
    option which caused the double precision math functions to be
    used regardless of the value of SUNDIALS_PRECISION.
  * Changed SUNDIALS_LOGGING_ENABLE_MPI CMake option default to be
  'OFF'.
- Split off sundials-sunlibs (previously libsundials4) into
  individual shared lib packages: libsundials_sunlinsol4_3_0,
  libsundials_sunmatrix4, and libsundials_sunnonlin3_3_0.
* Fri Sep  9 2022 Atri Bhattacharya <badshah400@gmail.com>
- Rename libsundials4 to sundials-sunlibs as it packages multiple
  shared libs pertaining to the main sundials library; shlib
  naming guidelines do not apply in this case.
- Drop no longer needed rpmlintrc file.
- Make -doc package into noarch.
* Thu Jul  7 2022 Klaus Kämpf <kkaempf@suse.com>
- add _constraints (boo#1201273)
* Mon Jun 27 2022 Klaus Kämpf <kkaempf@suse.com>
- Update to 6.2.0
  See https://github.com/LLNL/sundials/blob/main/CHANGELOG.md
- https://github.com/LLNL/sundials is now the official SUNDIALS
  development repository.
* Wed Apr 27 2022 Jan Engelhardt <jengelh@inai.de>
- Add rpmlintrc for shlib-policy-name-error
* Fri Feb 12 2021 Dirk Müller <dmueller@suse.com>
- update to 5.7.0:
  * A new NVECTOR implementation based on the SYCL abstraction layer has been added
    targeting Intel GPUs. At present the only SYCL compiler supported is the DPC++
    (Intel oneAPI) compiler. See the SYCL NVECTOR section in the user guide for
    more details. This module is considered experimental and is subject to major
    changes even in minor releases.
  * A new SUNMatrix and SUNLinearSolver implementation were added to interface with
    the MAGMA linear algebra library. Both the matrix and the linear solver support
    general dense linear systems as well as block diagonal linear systems, and both
    are targeted at GPUs (AMD or NVIDIA).
  * Fixed a bug in the SUNDIALS CMake which caused an error if the
    CMAKE_CXX_STANDARD and SUNDIALS_RAJA_BACKENDS options were not provided.
  * Fixed some compiler warnings when using the IBM XL compilers.
  * A new NVECTOR implementation based on the AMD ROCm HIP platform has been added.
    This vector can target NVIDIA or AMD GPUs. See HIP NVECTOR section in the user
    guide for more details. This module is considered experimental and is subject
    to change from version to version.
  * The RAJA NVECTOR implementation has been updated to support the HIP backend in
    addition to the CUDA backend. Users can choose the backend when configuring
    SUNDIALS by using the `SUNDIALS_RAJA_BACKENDS` CMake variable. This module
    remains experimental and is subject to change from version to version.
  * A new optional operation, `N_VGetDeviceArrayPointer`, was added to the N_Vector
    API. This operation is useful for N_Vectors that utilize dual memory spaces,
    e.g. the native SUNDIALS CUDA N_Vector.
  * The SUNMATRIX_CUSPARSE and SUNLINEARSOLVER_CUSOLVERSP_BATCHQR implementations
    no longer require the SUNDIALS CUDA N_Vector. Instead, they require that the
    vector utilized provides the `N_VGetDeviceArrayPointer` operation, and that the
    pointer returned by `N_VGetDeviceArrayPointer` is a valid CUDA device pointer.
- Minor refreshing of sundials-link-pthread.patch to apply cleanly
  against updated sources.
* Wed Dec  2 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.5.0:
  * Refactored the SUNDIALS CMake build system to improve build
    times by as much as 35%%.
  * CMake 3.12.0 or newer is now required.
  * Users will likely see CMake deprecation warnings, and
    potentially new errors when incompatible CMake options have
    been set (previously, these would fail silently).
  * SUNDIALS now exports CMake targets and installs a
    SUNDIALSConfig.cmake file.
  * Added support for SuperLU DIST 6.3.0+.
- Add sundials-link-pthread.patch: Link against pthread explicitly
  to fix linking errors when `-Wl,--no-undefined` is added to the
  linker flags; patch sent upstream.
- Add BuildRequires: suitesparse-devel and enable KLU solver; pass
  appropriate options to cmake to make sure the klu library and
  header is correctly found.
- Use cmake macros instead of manual cmake commands.
- Split out new libsundials_generic package with the
  libsundials_generic shared library.
- Enable openmpi4 flavour.
- Run tests except for tests that fail due to floating point
  errors in the tests themselves.
- Drop Group tags.
* Fri Sep 11 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.3.0:
  * Added support to CVODE for integrating IVPs with constraints
    using BDF methods and projecting the solution onto the
    constraint manifold with a user defined projection function.
  * Added the ability to control the CUDA kernel launch parameters
    for the NVECTOR_CUDA and SUNMATRIX_CUSPARSE modules.
  * The NVECTOR_CUDA kernels were rewritten to be more flexible.
  * Added new capabilities for monitoring the solve phase in the
    SUNNONLINSOL_NEWTON and SUNNONLINSOL_FIXEDPOINT modules, and
    the SUNDIALS iterative linear solver modules.
  * Added specialized fused CUDA kernels to CVODE which may offer
    better performance on smaller problems when using CVODE with
    the NVECTOR_CUDA module.
  * Added a new function, CVodeSetMonitorFn, that takes a
    user-function to be called by CVODE after every nst
    successfully completed time-steps.
  * Added a new function CVodeGetLinSolveStats to get the CVODE
    linear solver statistics as a group.
  * Added optional set functions to provide an alternative ODE
    right-hand side function (ARKode and CVODE(S)), DAE residual
    function (IDA(S)), or nonlinear system function (KINSOL) for
    use when computing Jacobian-vector products with the internal
    difference quotient approximation.
  * Fixed a bug in ARKode where the prototypes for
    ERKStepSetMinReduction() and ARKStepSetMinReduction() were not
    included in arkode_erkstep.h and arkode_arkstep.h
    respectively.
  * Fixed a bug in ARKode where inequality constraint checking
    would need to be disabled and then re-enabled to update the
    inequality constraint values after resizing a problem.
  * Fixed a bug in the iterative linear solver modules where an
    error is not returned if the Atimes function is NULL or, if
    preconditioning is enabled, the PSolve function is NULL.
- Pass SUNDIALS_BUILD_WITH_MONITORING=ON to cmake to enable
  monitoring the solve phase in different iterative solver
  modules.
* Sat May  9 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.2.0 (See
  https://computing.llnl.gov/projects/sundials/release-history for
  details):
  - Fixed a bug in how ARKode interfaces with a user-supplied,
    iterative, unscaled linear solver.
  - Fixed a bug in how ARKode interfaces with a user-supplied,
    iterative, unscaled linear solver.
  - Fixed a similar bug in how ARKode interfaces with scaled
    linear solvers when solving problems with non-identity mass
    matrices.
  - Fixed a memory leak in CVODES and IDAS from not deallocating
    the atolSmin0 and atolQSmin0 arrays.
  - Fixed a bug where a non-default value for the maximum allowed
    growth factor after the first step would be ignored.
  - Functions were added to each of the time integration packages
    to enable or disable the scaling applied to linear system
    solutions with matrix-based linear solvers to account for
    lagged matrix information.
  - Added two new functions, ARKStepSetMinReduction() and
    ERKStepSetMinReduction() to change the minimum allowed step
    size reduction factor after an error test failure.
  - Added a new SUNMatrix implementation, SUNMATRIX_CUSPARSE, that
    interfaces to the sparse matrix implementation from the NVIDIA
    cuSPARSE library.
  - Added a new "stiff" interpolation module to ARKode, based on
    Lagrange polynomial interpolation, that is accessible to each
    of the ARKStep, ERKStep and MRIStep time-stepping modules.
* Wed Jan 29 2020 Atri Bhattacharya <badshah400@gmail.com>
- Remove duplicated definitions.
- Remove bogus undefines of suffix and mpi_flavor for "serial"
  flavour. The former causes builds to fail for openSUSE >= 1550
  using rpm >= 4.15.
* Fri Nov  8 2019 Atri Bhattacharya <badshah400@gmail.com>
- Run spec-cleaner for minor cleanups.
* Thu Nov  7 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.0.0:
  * Two new NVector implementations created to support flexible
    partitioning of solution data among different processing
    elements (e.g., CPU + GPU) or for multi-physics problems that
    couple distinct MPI-based simulations together:
    NVECTOR_MANYVECTOR, amd NVECTOR_MPIMANYVECTOR,
  * An additional NVector implementation, NVECTOR_MPIPLUSX, has
    been created to support the MPI+X paradigm where X is a type
    of on-node parallelism (e.g., OpenMP, CUDA),
  * One new required NVector operation, N_VGetLength, and ten new
    optional vector operations have been added to the NVector API,
  * Two new SUNLinearSolver implementations,
    SUNLINEARSOLVER_SUPERLUDIST which interfaces with the
    SuperLU_DIST distributed, sparse, linear solver library, and
    the SUNLINEARSOLVER_CUSOLVERSP_BATCHQR, which interfaces to
    the cuSOLVE sparse batched QR linear solver,
  * A new SUNNonlinearSolver implementation,
    SUNNONLINSOL_PETSCSNES, which provides an interface to the
    PETSc SNES API,
  * New Fortran 2003 interface modules that provide Fortran users
    access to most of the SUNDIALS C API including ARKode,
    CVODE(S), IDA(S), and KINSOL,
  * Support for using explicit, implicit, or IMEX methods as the
    fast integrator with the MRIStep time-stepper in ARKode,
  * Several other minor changes and bug fixes: see
    https://computing.llnl.gov/projects/sundials/release-history.
- Merge all nvec solver libraries into a single shared lib
  package: %%{shlib_nvec}.
* Thu Nov  7 2019 Atri Bhattacharya <badshah400@gmail.com>
- Enable multibuild with serial, openmpi1, openmpi2, openmpi3,
  and mvapich2 flavours.
* Wed Apr 10 2019 Atri Bhattacharya <badshah400@gmail.com>
- Follow shared library packaging policy and split out multiple
  versioned shlib packages. The main shared lib %%{shlib_main}
  contains the common shared objects, while each individual solver
  gets its own shared lib package.
- Add blas-devel and lapack-devel BuildRequires; enable blas and
  lapack (does not work with 64 bits) during cmake.
- Enable pthread.
* Wed Apr 10 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 4.1.0:
  * An additional N_Vector implementation was added for Tpetra
    vector from Trilinos library to facilitate interoperability
    between SUNDIALS and Trilinos. This implementation is
    accompanied by additions to user documentation and SUNDIALS
    examples.
  * A bug was fixed where a nonlinear solver object could be freed
    twice in some use cases.
  * The EXAMPLES_ENABLE_RAJA CMake option has been removed. The
    option EXAMPLES_ENABLE_CUDA enables all examples that use CUDA
    including the RAJA examples with a CUDA back end (if the RAJA
    NVECTOR is enabled).
  * The implementation header files (e.g. arkode_impl.h) are no
    longer installed. This means users who are directly
    manipulating package memory structures will need to update
    their code to use the package’s public API.
  * Python is no longer required to run make test and make
    test_install.
  * Fixed a bug in ARKodeButcherTable_Write when printing a
    Butcher table without an embedding.
- Changes between previously packaged version (2.5.0) through
  version 4.0.2:
  https://computation.llnl.gov/projects/sundials/release-history.
- Switch to cmake based build in keeping with upstream.
- Drop devel-static package since application no longer builds
  static libraries anyway.
- Only build one (serial) version for now.
- Update Source and URL tags.
- Remove NOTICE and LICENSE files from includedir; package them
  properly as doc.
* Sat Jun  2 2012 scorot@free.fr
- fix mistyping in spec file which broke build where mvapich2
  is not available
* Sat Jun  2 2012 scorot@free.fr
- set --with-mpi-libs in configure in order to fix mpi library
  linking
* Sat Jun  2 2012 scorot@free.fr
- enable parallel build for openmpi and mvapich2
* Sat Jun  2 2012 scorot@free.fr
- remove not applied patch0 from files list
* Sat Jun  2 2012 scorot@free.fr
- spec files re-formating
- version 2.5.0
  * Many bugfixes and new features
  * See https://computation.llnl.gov/casc/sundials/download/
  whatsnew.html for a complete list of changes
